drawinglayer/source/processor2d/helperchartrenderer.cxx    |    2 +-
 oox/inc/oox/xls/condformatbuffer.hxx                       |    4 ++--
 oox/inc/oox/xls/worksheethelper.hxx                        |    2 +-
 oox/source/xls/worksheethelper.cxx                         |    4 ++--
 sc/source/filter/inc/xicontent.hxx                         |    4 ++--
 sc/source/filter/inc/xiroot.hxx                            |    4 ++--
 sfx2/source/doc/doc.src                                    |    2 +-
 testautomation/writer/optional/includes/number/w_205a_.inc |    4 ++--
 testautomation/writer/optional/includes/number/w_207_.inc  |    2 +-
 9 files changed, 14 insertions(+), 14 deletions(-)

New commits:
commit 37f509e15d74e005cbe264dd27106359c4165657
Author: Lior Kaplan <kaplanl...@gmail.com>
Date:   Tue Nov 29 18:17:18 2011 +0200

    Replace formattings with formatting

diff --git a/drawinglayer/source/processor2d/helperchartrenderer.cxx 
b/drawinglayer/source/processor2d/helperchartrenderer.cxx
index 84e70ec..bf7dec5 100644
--- a/drawinglayer/source/processor2d/helperchartrenderer.cxx
+++ b/drawinglayer/source/processor2d/helperchartrenderer.cxx
@@ -90,7 +90,7 @@ namespace drawinglayer
                             // needs to be expressed in the MapMode for the 
PrettyPainter;
                             // else it would call 
ChartModelHelper::setPageSize(...) with the
                             // changed size what really will change the chart 
model and leads
-                            // to re-layouts and re-formattings
+                            // to re-layouts and re-formatting
                             const MapMode 
aOldMapMode(rOutputDevice.GetMapMode());
                             basegfx::B2DVector aVTScale, aScale, aTranslate;
                             double fRotate, fShearX;
diff --git a/oox/inc/oox/xls/worksheethelper.hxx 
b/oox/inc/oox/xls/worksheethelper.hxx
index c824c4e..33ae0a8 100644
--- a/oox/inc/oox/xls/worksheethelper.hxx
+++ b/oox/inc/oox/xls/worksheethelper.hxx
@@ -255,7 +255,7 @@ public:
 
     /** Returns the buffer for cell contents and cell formatting. */
     SheetDataBuffer&    getSheetData() const;
-    /** Returns the conditional formattings in this sheet. */
+    /** Returns the conditional formatting in this sheet. */
     CondFormatBuffer&   getCondFormats() const;
     /** Returns the buffer for all cell comments in this sheet. */
     CommentsBuffer&     getComments() const;
diff --git a/oox/source/xls/worksheethelper.cxx 
b/oox/source/xls/worksheethelper.cxx
index ba5014f..e8a2972 100644
--- a/oox/source/xls/worksheethelper.cxx
+++ b/oox/source/xls/worksheethelper.cxx
@@ -277,7 +277,7 @@ public:
 
     /** Returns the buffer for cell contents and cell formatting. */
     inline SheetDataBuffer& getSheetData() { return maSheetData; }
-    /** Returns the conditional formattings in this sheet. */
+    /** Returns the conditional formatting in this sheet. */
     inline CondFormatBuffer& getCondFormats() { return maCondFormats; }
     /** Returns the buffer for all cell comments in this sheet. */
     inline CommentsBuffer& getComments() { return maComments; }
@@ -396,7 +396,7 @@ private:
     ValidationModelList maValidations;      /// Cell ranges containing data 
validation settings.
     ValueRangeSet       maManualRowHeights; /// Rows that need manual height 
independent from own settings.
     SheetDataBuffer     maSheetData;        /// Buffer for cell contents and 
cell formatting.
-    CondFormatBuffer    maCondFormats;      /// Buffer for conditional 
formattings.
+    CondFormatBuffer    maCondFormats;      /// Buffer for conditional 
formatting.
     CommentsBuffer      maComments;         /// Buffer for all cell comments 
in this sheet.
     AutoFilterBuffer    maAutoFilters;      /// Sheet auto filters (not 
associated to a table).
     QueryTableBuffer    maQueryTables;      /// Buffer for all web query 
tables in this sheet.
diff --git a/sc/source/filter/inc/xicontent.hxx 
b/sc/source/filter/inc/xicontent.hxx
index 31a62ab..576e41b 100644
--- a/sc/source/filter/inc/xicontent.hxx
+++ b/sc/source/filter/inc/xicontent.hxx
@@ -168,12 +168,12 @@ public:
     /** Reads a CF record and inserts the formatting data to the current 
conditional format. */
     void                ReadCF( XclImpStream& rStrm );
 
-    /** Inserts the conditional formattings into the document. */
+    /** Inserts the conditional formatting into the document. */
     void                Apply();
 
 private:
     typedef boost::ptr_vector< XclImpCondFormat > XclImpCondFmtList;
-    XclImpCondFmtList   maCondFmtList;      /// List with all conditional 
formattings.
+    XclImpCondFmtList   maCondFmtList;      /// List with all conditional 
formatting.
 };
 
 // Data Validation ============================================================
diff --git a/sfx2/source/doc/doc.src b/sfx2/source/doc/doc.src
index bb72e07..4d99ae1 100644
--- a/sfx2/source/doc/doc.src
+++ b/sfx2/source/doc/doc.src
@@ -486,7 +486,7 @@ QueryBox MSG_XMLSEC_QUERY_SAVESIGNEDBEFORESIGN
 
 String STR_QRYTEMPL_MESSAGE
 {
-    Text [ en-US ] = "The template '$(ARG1)' on which this document is based, 
has been modified. Do you want to update style based formattings according to 
the modified template?";
+    Text [ en-US ] = "The template '$(ARG1)' on which this document is based, 
has been modified. Do you want to update style based formatting according to 
the modified template?";
 };
 
 String STR_QRYTEMPL_UPDATE_BTN
diff --git a/testautomation/writer/optional/includes/number/w_205a_.inc 
b/testautomation/writer/optional/includes/number/w_205a_.inc
index 0d28539..579ea24 100644
--- a/testautomation/writer/optional/includes/number/w_205a_.inc
+++ b/testautomation/writer/optional/includes/number/w_205a_.inc
@@ -239,10 +239,10 @@ testcase tToolsOutlineNumbering1
     for i = 1 to 2
         Select Case i
             Case 1
-                printlog "- Load sxw and check formattings"
+                printlog "- Load sxw and check formatting"
                 hFileOpen( gOfficePath & 
"user\work\tToolsOutlineNumbering1.sxw" )
             Case 2
-                printlog "- Load odt and check formattings"
+                printlog "- Load odt and check formatting"
                 hFileOpen( gOfficePath & 
"user\work\tToolsOutlineNumbering1.odt" )
         end select
         call wTypeKeys "<PageUp>", 8
diff --git a/testautomation/writer/optional/includes/number/w_207_.inc 
b/testautomation/writer/optional/includes/number/w_207_.inc
index 972f230..1836987 100644
--- a/testautomation/writer/optional/includes/number/w_207_.inc
+++ b/testautomation/writer/optional/includes/number/w_207_.inc
@@ -132,7 +132,7 @@ testcase tToolsNumbering13
 
     Dim i as integer, iCounter as integer
     '/// #i73790 Regression testing 
-    '/// This testcase loads a Worddocument that lost all formattings
+    '/// This testcase loads a Worddocument that lost all formatting
     printlog "#i73790 regression testing"
     '/// Load document 'writer\\optional\\input\\number\\regression\\73790.doc'
     hFileOpenLocally(  gTesttoolPath + 
"writer\optional\input\number\regression\73790.doc" )
_______________________________________________
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/oox/inc/oox/xls/condformatbuffer.hxx 
b/oox/inc/oox/xls/condformatbuffer.hxx
index 3dba25b..4354178 100644
--- a/oox/inc/oox/xls/condformatbuffer.hxx
+++ b/oox/inc/oox/xls/condformatbuffer.hxx
@@ -171,7 +171,7 @@ public:
     /** Imports settings from the CFHEADER record. */
     void                importCfHeader( BiffInputStream& rStrm );
 
     /** Creates all conditional formattings in the Calc document. */
     void                finalizeImport();
 
     /** Converts an OOXML condition operator token to the API constant. */
@@ -182,7 +182,7 @@ private:
 
 private:
     typedef RefVector< CondFormat > CondFormatVec;
-    CondFormatVec       maCondFormats;      /// All conditional formattings in 
a sheet.
+    CondFormatVec       maCondFormats;      /// All conditional formatting in 
a sheet.
 };
 
@@ -171,7 +171,7 @@ public:
     void                importCfHeader( BiffInputStream& rStrm );
 
-    /** Creates all conditional formattings in the Calc document. */
+    /** Creates all conditional formatting in the Calc document. */
     void                finalizeImport();
 
 // ============================================================================
diff --git a/sc/source/filter/inc/xiroot.hxx b/sc/source/filter/inc/xiroot.hxx
index 653d39c..8bf1a7c 100644
--- a/sc/source/filter/inc/xiroot.hxx
+++ b/sc/source/filter/inc/xiroot.hxx
@@ -109,7 +109,7 @@ struct XclImpRootData : public XclRootData
     XclImpLinkMgrRef    mxLinkMgr;          /// Manager for internal/external 
links.
 
     XclImpObjectMgrRef  mxObjMgr;           /// All drawing objects.
-    XclImpCondFmtMgrRef mxCondFmtMgr;       /// Conditional formattings.
+    XclImpCondFmtMgrRef mxCondFmtMgr;       /// Conditional formatting.
     XclImpValidationMgrRef mxValidMgr;      /// Data validation
     XclImpWebQueryBfrRef mxWebQueryBfr;     /// All web queries.
     XclImpPTableMgrRef  mxPTableMgr;        /// All pivot tables and pivot 
caches.
@@ -185,7 +185,7 @@ public:
     XclImpObjectManager& GetObjectManager() const;
     /** Returns the drawing container of the current sheet. */
     XclImpSheetDrawing& GetCurrSheetDrawing() const;
     /** Returns the conditional formattings manager. */
     XclImpCondFormatManager& GetCondFormatManager() const;
 
     XclImpValidationManager& GetValidationManager() const;
@@ -185,7 +185,7 @@ public:
     /** Returns the drawing container of the current sheet. */
     XclImpSheetDrawing& GetCurrSheetDrawing() const;
-    /** Returns the conditional formattings manager. */
+    /** Returns the conditional formatting manager. */
     XclImpCondFormatManager& GetCondFormatManager() const;
 